Documentation
¶
Index ¶
- type Properties
- type Run
- func (r *Run) Bold() *Run
- func (r *Run) Color(color ...any) *Run
- func (r *Run) Font(font ...string) *Run
- func (r *Run) Highlight(val string) *Run
- func (r *Run) Italic() *Run
- func (r *Run) Shade(val, color, fill string) *Run
- func (r *Run) Size(size float64) *Run
- func (r *Run) Underline(val string) *Run
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Run ¶
type Run struct {
XMLName xml.Name `xml:"w:r,omitempty"`
Space string `xml:"xml:space,attr,omitempty"`
Properties *Properties `xml:"w:rPr,omitempty"`
InstrText string `xml:"w:instrText,omitempty"`
Text string `xml:"w:t"`
}
func (*Run) Font ¶
Font sets the font of the run font []string = []string{"楷体"} 或 []string{ASCII,EastAsia,HAnsi,Cs,Hint}
func (*Run) Underline ¶
Underline 可选如下:
dash - a dashed line dashDotDotHeavy - a series of thick dash, dot, dot characters dashDotHeavy - a series of thick dash, dot characters dashedHeavy - a series of thick dashes dashLong - a series of long dashed characters dashLongHeavy - a series of thick, long, dashed characters dotDash - a series of dash, dot characters dotDotDash - a series of dash, dot, dot characters dotted - a series of dot characters dottedHeavy - a series of thick dot characters double - two lines none - no underline single - a single line thick - a single think line wave - a single wavy line wavyDouble - a pair of wavy lines wavyHeavy - a single thick wavy line words - a single line beneath all non-space characters
Click to show internal directories.
Click to hide internal directories.